auto-requirements
=================

auto format requirements file

``python auto_requirements.py requirements.txt``

Release Log:
============

version 2016.3.15.1
-------------------

1. fix requirements
2. fix autoreq parsing issues, which will fail while a package name
   contains ‘.’

thanks cloverhsc report this bug
https://github.com/lucemia/autoreq/issues/4
